@@ -23,15 +23,19 @@
 Direct terminal UI implementation
 """
 
-import fcntl
-import termios
 import os
 import select
 import struct
 import sys
-import tty
 import signal
 
+try:
+    import fcntl
+    import termios
+    import tty
+except ImportError:
+    pass # windows
+
 from urwid import util
 from urwid import escape
 from urwid.display_common import BaseScreen, RealTerminal, \
@@ -678,7 +682,7 @@ class Screen(BaseScreen, RealTerminal):
         cy = 0
         for row in r.content():
             y += 1
-            if False and osb and osb[y] == row:
+            if osb and osb[y] == row:
                 # this row of the screen buffer matches what is
                 # currently displayed, so we can skip this line
                 sb.append( osb[y] )
